Module: Google::Cloud::ManagedIdentities::V1::Domain::State
- Defined in:
- proto_docs/google/cloud/managedidentities/v1/resource.rb
Overview
Represents the different states of a managed domain.
Constant Summary collapse
- STATE_UNSPECIFIED =
Not set.
0- CREATING =
The domain is being created.
1- READY =
The domain has been created and is fully usable.
2- UPDATING =
The domain's configuration is being updated.
3- DELETING =
The domain is being deleted.
4- REPAIRING =
The domain is being repaired and may be unusable. Details can be found in the
status_messagefield. 5- PERFORMING_MAINTENANCE =
The domain is undergoing maintenance.
6- UNAVAILABLE =
The domain is not serving requests.
7