Class: Google::Cloud::ManagedIdentities::V1::ManagedIdentitiesService::Client
- Inherits:
-
Object
- Object
- Google::Cloud::ManagedIdentities::V1::ManagedIdentitiesService::Client
- Includes:
- Paths
- Defined in:
- lib/google/cloud/managed_identities/v1/managed_identities_service/client.rb
Overview
Client for the ManagedIdentitiesService service.
API Overview
The managedidentites.googleapis.com service implements the Google Cloud
Managed Identites API for identity services
(e.g. Microsoft Active Directory).
The Managed Identities service provides methods to manage (create/read/update/delete) domains, reset managed identities admin password, add/remove domain controllers in GCP regions and add/remove VPC peering.
Data Model
The Managed Identities service exposes the following resources:
Locations as global, named as follows:
projects/{project_id}/locations/global.Domains, named as follows:
/projects/{project_id}/locations/global/domain/{domain_name}.
The {domain_name} refers to fully qualified domain name in the customer
project e.g. mydomain.myorganization.com, with the following restrictions:
- Must contain only lowercase letters, numbers, periods and hyphens.
- Must start with a letter.
- Must contain between 2-64 characters.
- Must end with a number or a letter.
- Must not start with period.
- First segement length (mydomain form example above) shouldn't exceed 15 chars.
- The last segment cannot be fully numeric.
- Must be unique within the customer project.
Defined Under Namespace
Classes: Configuration
Instance Attribute Summary collapse
-
#operations_client ⇒ ::Google::Cloud::ManagedIdentities::V1::ManagedIdentitiesService::Operations
readonly
Get the associated client for long-running operations.
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the ManagedIdentitiesService Client class.
Instance Method Summary collapse
-
#attach_trust(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::Operation
Adds an AD trust to a domain.
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the ManagedIdentitiesService Client instance.
-
#create_microsoft_ad_domain(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::Operation
Creates a Microsoft AD domain.
-
#delete_domain(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::Operation
Deletes a domain.
-
#detach_trust(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::Operation
Removes an AD trust.
-
#get_domain(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::ManagedIdentities::V1::Domain
Gets information about a domain.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new ManagedIdentitiesService client object.
-
#list_domains(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::ManagedIdentities::V1::Domain>
Lists domains in a project.
-
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#reconfigure_trust(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::Operation
Updates the DNS conditional forwarder.
-
#reset_admin_password(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::ManagedIdentities::V1::ResetAdminPasswordResponse
Resets a domain's administrator password.
-
#universe_domain ⇒ String
The effective universe domain.
-
#update_domain(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::Operation
Updates the metadata and configuration of a domain.
-
#validate_trust(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::Operation
Validates a trust state, that the target domain is reachable, and that the target domain is able to accept incoming trust requests.
Methods included from Paths
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new ManagedIdentitiesService client object.
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/google/cloud/managed_identities/v1/managed_identities_service/client.rb', line 175 def initialize # These require statements are intentionally placed here to initialize # the gRPC module only when it's required. # See https://github.com/googleapis/toolkit/issues/446 require "gapic/grpc" require "google/cloud/managedidentities/v1/managed_identities_service_services_pb" # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @operations_client = Operations.new do |config| config.credentials = credentials config.quota_project = @quota_project_id config.endpoint = @config.endpoint config.universe_domain = @config.universe_domain end @managed_identities_service_stub = ::Gapic::ServiceStub.new( ::Google::Cloud::ManagedIdentities::V1::ManagedIdentitiesService::Stub, credentials: credentials, endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, channel_args: @config.channel_args, interceptors: @config.interceptors, channel_pool_config: @config.channel_pool, logger: @config.logger ) @managed_identities_service_stub.stub_logger&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end end |
Instance Attribute Details
#operations_client ⇒ ::Google::Cloud::ManagedIdentities::V1::ManagedIdentitiesService::Operations (readonly)
Get the associated client for long-running operations.
238 239 240 |
# File 'lib/google/cloud/managed_identities/v1/managed_identities_service/client.rb', line 238 def operations_client @operations_client end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the ManagedIdentitiesService Client class.
See Configuration for a description of the configuration fields.
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/google/cloud/managed_identities/v1/managed_identities_service/client.rb', line 93 def self.configure @configure ||= begin namespace = ["Google", "Cloud", "ManagedIdentities", "V1"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config.rpcs.create_microsoft_ad_domain.timeout = 60.0 default_config.rpcs.reset_admin_password.timeout = 60.0 default_config.rpcs.list_domains.timeout = 60.0 default_config.rpcs.get_domain.timeout = 60.0 default_config.rpcs.update_domain.timeout = 60.0 default_config.rpcs.delete_domain.timeout = 60.0 default_config.rpcs.attach_trust.timeout = 60.0 default_config.rpcs.reconfigure_trust.timeout = 60.0 default_config.rpcs.detach_trust.timeout = 60.0 default_config.rpcs.validate_trust.timeout = 60.0 default_config end yield @configure if block_given? @configure end |
Instance Method Details
#attach_trust(request, options = nil) ⇒ ::Gapic::Operation #attach_trust(name: nil, trust: nil) ⇒ ::Gapic::Operation
Adds an AD trust to a domain.
894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 |
# File 'lib/google/cloud/managed_identities/v1/managed_identities_service/client.rb', line 894 def attach_trust request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::ManagedIdentities::V1::AttachTrustRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.attach_trust..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::ManagedIdentities::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.attach_trust.timeout, metadata: , retry_policy: @config.rpcs.attach_trust.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @managed_identities_service_stub.call_rpc :attach_trust, request, options: do |response, operation| response = ::Gapic::Operation.new response, @operations_client, options: yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#configure {|config| ... } ⇒ Client::Configuration
Configure the ManagedIdentitiesService Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
145 146 147 148 |
# File 'lib/google/cloud/managed_identities/v1/managed_identities_service/client.rb', line 145 def configure yield @config if block_given? @config end |
#create_microsoft_ad_domain(request, options = nil) ⇒ ::Gapic::Operation #create_microsoft_ad_domain(parent: nil, domain_name: nil, domain: nil) ⇒ ::Gapic::Operation
Creates a Microsoft AD domain.
318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 |
# File 'lib/google/cloud/managed_identities/v1/managed_identities_service/client.rb', line 318 def create_microsoft_ad_domain request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::ManagedIdentities::V1::CreateMicrosoftAdDomainRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_microsoft_ad_domain..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::ManagedIdentities::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.create_microsoft_ad_domain.timeout, metadata: , retry_policy: @config.rpcs.create_microsoft_ad_domain.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @managed_identities_service_stub.call_rpc :create_microsoft_ad_domain, request, options: do |response, operation| response = ::Gapic::Operation.new response, @operations_client, options: yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#delete_domain(request, options = nil) ⇒ ::Gapic::Operation #delete_domain(name: nil) ⇒ ::Gapic::Operation
Deletes a domain.
797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 |
# File 'lib/google/cloud/managed_identities/v1/managed_identities_service/client.rb', line 797 def delete_domain request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::ManagedIdentities::V1::DeleteDomainRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.delete_domain..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::ManagedIdentities::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.delete_domain.timeout, metadata: , retry_policy: @config.rpcs.delete_domain.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @managed_identities_service_stub.call_rpc :delete_domain, request, options: do |response, operation| response = ::Gapic::Operation.new response, @operations_client, options: yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#detach_trust(request, options = nil) ⇒ ::Gapic::Operation #detach_trust(name: nil, trust: nil) ⇒ ::Gapic::Operation
Removes an AD trust.
1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 |
# File 'lib/google/cloud/managed_identities/v1/managed_identities_service/client.rb', line 1092 def detach_trust request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::ManagedIdentities::V1::DetachTrustRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.detach_trust..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::ManagedIdentities::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.detach_trust.timeout, metadata: , retry_policy: @config.rpcs.detach_trust.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @managed_identities_service_stub.call_rpc :detach_trust, request, options: do |response, operation| response = ::Gapic::Operation.new response, @operations_client, options: yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#get_domain(request, options = nil) ⇒ ::Google::Cloud::ManagedIdentities::V1::Domain #get_domain(name: nil) ⇒ ::Google::Cloud::ManagedIdentities::V1::Domain
Gets information about a domain.
602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'lib/google/cloud/managed_identities/v1/managed_identities_service/client.rb', line 602 def get_domain request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::ManagedIdentities::V1::GetDomainRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_domain..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::ManagedIdentities::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.get_domain.timeout, metadata: , retry_policy: @config.rpcs.get_domain.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @managed_identities_service_stub.call_rpc :get_domain, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#list_domains(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::ManagedIdentities::V1::Domain> #list_domains(parent: nil, page_size: nil, page_token: nil, filter: nil, order_by: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::ManagedIdentities::V1::Domain>
Lists domains in a project.
514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 |
# File 'lib/google/cloud/managed_identities/v1/managed_identities_service/client.rb', line 514 def list_domains request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::ManagedIdentities::V1::ListDomainsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_domains..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::ManagedIdentities::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.list_domains.timeout, metadata: , retry_policy: @config.rpcs.list_domains.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @managed_identities_service_stub.call_rpc :list_domains, request, options: do |response, operation| response = ::Gapic::PagedEnumerable.new @managed_identities_service_stub, :list_domains, request, response, operation, yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#logger ⇒ Logger
The logger used for request/response debug logging.
245 246 247 |
# File 'lib/google/cloud/managed_identities/v1/managed_identities_service/client.rb', line 245 def logger @managed_identities_service_stub.logger end |
#reconfigure_trust(request, options = nil) ⇒ ::Gapic::Operation #reconfigure_trust(name: nil, target_domain_name: nil, target_dns_ip_addresses: nil) ⇒ ::Gapic::Operation
Updates the DNS conditional forwarder.
995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 |
# File 'lib/google/cloud/managed_identities/v1/managed_identities_service/client.rb', line 995 def reconfigure_trust request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::ManagedIdentities::V1::ReconfigureTrustRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.reconfigure_trust..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::ManagedIdentities::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.reconfigure_trust.timeout, metadata: , retry_policy: @config.rpcs.reconfigure_trust.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @managed_identities_service_stub.call_rpc :reconfigure_trust, request, options: do |response, operation| response = ::Gapic::Operation.new response, @operations_client, options: yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#reset_admin_password(request, options = nil) ⇒ ::Google::Cloud::ManagedIdentities::V1::ResetAdminPasswordResponse #reset_admin_password(name: nil) ⇒ ::Google::Cloud::ManagedIdentities::V1::ResetAdminPasswordResponse
Resets a domain's administrator password.
406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 |
# File 'lib/google/cloud/managed_identities/v1/managed_identities_service/client.rb', line 406 def reset_admin_password request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::ManagedIdentities::V1::ResetAdminPasswordRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.reset_admin_password..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::ManagedIdentities::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.reset_admin_password.timeout, metadata: , retry_policy: @config.rpcs.reset_admin_password.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @managed_identities_service_stub.call_rpc :reset_admin_password, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#universe_domain ⇒ String
The effective universe domain
155 156 157 |
# File 'lib/google/cloud/managed_identities/v1/managed_identities_service/client.rb', line 155 def universe_domain @managed_identities_service_stub.universe_domain end |
#update_domain(request, options = nil) ⇒ ::Gapic::Operation #update_domain(update_mask: nil, domain: nil) ⇒ ::Gapic::Operation
Updates the metadata and configuration of a domain.
702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 |
# File 'lib/google/cloud/managed_identities/v1/managed_identities_service/client.rb', line 702 def update_domain request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::ManagedIdentities::V1::UpdateDomainRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_domain..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::ManagedIdentities::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.domain&.name header_params["domain.name"] = request.domain.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.update_domain.timeout, metadata: , retry_policy: @config.rpcs.update_domain.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @managed_identities_service_stub.call_rpc :update_domain, request, options: do |response, operation| response = ::Gapic::Operation.new response, @operations_client, options: yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#validate_trust(request, options = nil) ⇒ ::Gapic::Operation #validate_trust(name: nil, trust: nil) ⇒ ::Gapic::Operation
Validates a trust state, that the target domain is reachable, and that the target domain is able to accept incoming trust requests.
1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 1224 1225 1226 1227 1228 1229 1230 1231 |
# File 'lib/google/cloud/managed_identities/v1/managed_identities_service/client.rb', line 1190 def validate_trust request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::ManagedIdentities::V1::ValidateTrustRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.validate_trust..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::ManagedIdentities::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.validate_trust.timeout, metadata: , retry_policy: @config.rpcs.validate_trust.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @managed_identities_service_stub.call_rpc :validate_trust, request, options: do |response, operation| response = ::Gapic::Operation.new response, @operations_client, options: yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |